==> billogram-foundation-4.6.4.tgz: package/modules/components/dropdown/DropdownState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import { dropdownOptionsShape } from './utils/propTypes';
import getHighlightedIndex from './utils/getHighlightedIndex';


export default ({
    Component
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    return React.createClass({

        displayName: `${Component.displayName}State`,

        mixins: [PureRenderMixin],

        propTypes: {
            initialValue: PropTypes.any,
            onChange: PropTypes.func,
            options: dropdownOptionsShape
        },

        getDefaultProps() {
            return {
                initialValue: '',
                onChange: (/* value */) => {},
                options: []
            };
        },

        getInitialState() {
            const { initialValue: value } = this.props;
            return {
                expanded: false,
                highlightedIndex: -1,
                value
            };
        },

        componentWillReceiveProps(nextProps) {
            if (nextProps.initialValue !== this.props.initialValue) {
                // needed when the dropdown is used as a navigation menu.
                this.setState({ value: nextProps.initialValue });
            }
        },

        onChange(value) {
            this.setState({
                expanded: false,
                highlighedIndex: -1,
                value
            }, () => this.props.onChange(value));
        },

        onCollapse() {
            this.setState({
                expanded: false,
                highlightedIndex: -1
            });
        },

        onExpand() {
            const { options } = this.props;
            const { value } = this.state;
            const highlightedIndex = getHighlightedIndex({ options, value });

            this.setState({
                expanded: true,
                highlightedIndex
            });
        },

        onHighlightedIndexChange(highlightedIndex) {
            this.setState({
                highlightedIndex
            });
        },

        render() {
            return (
                <Component
                    { ...this.props }
                    { ...this.state }
                    onChange={ this.onChange }
                    onCollapse={ this.onCollapse }
                    onExpand={ this.onExpand }
                    onHighlightedIndexChange={ this.onHighlightedIndexChange } />
            );
        }

    });

};

==> billogram-foundation-4.7.7.tgz: package/modules/components/dropdown/DropdownState.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import { dropdownOptionsShape } from './utils/propTypes';
import getHighlightedIndex from './utils/getHighlightedIndex';


export default ({
    Component,
} = {}) => {

    invariant(Component !== undefined, 'Missing Dropdown component.');

    return React.createClass({

        displayName: `${Component.displayName}State`,

        mixins: [PureRenderMixin],

        propTypes: {
            initialValue: PropTypes.any,
            onChange: PropTypes.func,
            options: dropdownOptionsShape,
        },

        getDefaultProps() {
            return {
                initialValue: '',
                onChange: (/* value */) => {},
                options: [],
            };
        },

        getInitialState() {
            const { initialValue: value } = this.props;
            return {
                expanded: false,
                highlightedIndex: -1,
                value,
            };
        },

        componentWillReceiveProps(nextProps) {
            if (nextProps.initialValue !== this.props.initialValue) {
                // needed when the dropdown is used as a navigation menu.
                this.setState({ value: nextProps.initialValue });
            }
        },

        onChange(value) {
            this.setState({
                expanded: false,
                highlighedIndex: -1,
                value,
            }, () => this.props.onChange(value));
        },

        onCollapse() {
            this.setState({
                expanded: false,
                highlightedIndex: -1,
            });
        },

        onExpand() {
            const { options } = this.props;
            const { value } = this.state;
            const highlightedIndex = getHighlightedIndex({ options, value });

            this.setState({
                expanded: true,
                highlightedIndex,
            });
        },

        onHighlightedIndexChange(highlightedIndex) {
            this.setState({
                highlightedIndex,
            });
        },

        render() {
            return (
                <Component
                    { ...this.props }
                    { ...this.state }
                    onChange={ this.onChange }
                    onCollapse={ this.onCollapse }
                    onExpand={ this.onExpand }
                    onHighlightedIndexChange={ this.onHighlightedIndexChange } />
            );
        },

    });

};
